diff --git a/pom.xml b/pom.xml
index c719fe2..edbc2df 100644
--- a/pom.xml
+++ b/pom.xml
@@ -13,7 +13,7 @@
com.loafle.overflow
commons-java
jar
- 1.0.38-SNAPSHOT
+ 1.0.39-SNAPSHOT
com.loafle.overflow.commons-java
diff --git a/src/main/java/com/loafle/overflow/model/infra/InfraHostMachine.java b/src/main/java/com/loafle/overflow/model/infra/InfraHostMachine.java
index bd620ab..172168b 100644
--- a/src/main/java/com/loafle/overflow/model/infra/InfraHostMachine.java
+++ b/src/main/java/com/loafle/overflow/model/infra/InfraHostMachine.java
@@ -36,7 +36,7 @@ public class InfraHostMachine {
}
@Basic
- @Column(name = "META", nullable = true)
+ @Column(name = "META", nullable = true, length = 2000)
public String getMeta() {
return meta;
}
diff --git a/src/main/java/com/loafle/overflow/model/infra/InfraHostOS.java b/src/main/java/com/loafle/overflow/model/infra/InfraHostOS.java
index a0b886a..9747542 100644
--- a/src/main/java/com/loafle/overflow/model/infra/InfraHostOS.java
+++ b/src/main/java/com/loafle/overflow/model/infra/InfraHostOS.java
@@ -12,6 +12,13 @@ import java.util.Date;
public class InfraHostOS {
private Long id;
private InfraHost infraHost;
+ private String name;
+ private String os;
+ private String platform;
+ private String platformFamily;
+ private String platformVersion;
+ private String kernelVersion;
+ private String hostID;
private String meta;
private Date createDate;
@@ -35,8 +42,120 @@ public class InfraHostOS {
this.infraHost = infraHost;
}
+ /**
+ * @return the name
+ */
@Basic
- @Column(name = "META", nullable = true)
+ @Column(name = "NAME", nullable = true, length = 100)
+ public String getName() {
+ return name;
+ }
+
+ /**
+ * @param name the name to set
+ */
+ public void setName(String name) {
+ this.name = name;
+ }
+
+ /**
+ * @return the os
+ */
+ @Basic
+ @Column(name = "OS", nullable = true, length = 100)
+ public String getOs() {
+ return os;
+ }
+
+ /**
+ * @param os the os to set
+ */
+ public void setOs(String os) {
+ this.os = os;
+ }
+
+ /**
+ * @return the platform
+ */
+ @Basic
+ @Column(name = "PLATFORM", nullable = true, length = 100)
+ public String getPlatform() {
+ return platform;
+ }
+
+ /**
+ * @param platform the platform to set
+ */
+ public void setPlatform(String platform) {
+ this.platform = platform;
+ }
+
+ /**
+ * @return the platformFamily
+ */
+ @Basic
+ @Column(name = "PLATFORM_FAMILY", nullable = true, length = 100)
+ public String getPlatformFamily() {
+ return platformFamily;
+ }
+
+ /**
+ * @param platformFamily the platformFamily to set
+ */
+ public void setPlatformFamily(String platformFamily) {
+ this.platformFamily = platformFamily;
+ }
+
+ /**
+ * @return the platformVersion
+ */
+ @Basic
+ @Column(name = "PLATFORM_VERSION", nullable = true, length = 100)
+ public String getPlatformVersion() {
+ return platformVersion;
+ }
+
+ /**
+ * @param platformVersion the platformVersion to set
+ */
+ public void setPlatformVersion(String platformVersion) {
+ this.platformVersion = platformVersion;
+ }
+
+ /**
+ * @return the kernelVersion
+ */
+ @Basic
+ @Column(name = "KERNEL_VERSION", nullable = true, length = 100)
+ public String getKernelVersion() {
+ return kernelVersion;
+ }
+
+ /**
+ * @param kernelVersion the kernelVersion to set
+ */
+ public void setKernelVersion(String kernelVersion) {
+ this.kernelVersion = kernelVersion;
+ }
+
+ /**
+ * @return the hostID
+ */
+ @Basic
+ @Column(name = "HOST_ID", nullable = true, length = 50)
+ public String getHostID() {
+ return hostID;
+ }
+
+ /**
+ * @param hostID the hostID to set
+ */
+ public void setHostID(String hostID) {
+ this.hostID = hostID;
+ }
+
+ @Basic
+ @Column(name = "META", nullable = true, length = 2000)
public String getMeta() {
return meta;
}
@@ -45,7 +164,6 @@ public class InfraHostOS {
this.meta = meta;
}
-
@Temporal(TemporalType.TIMESTAMP)
@Column(name = "CREATE_DATE", nullable = false, columnDefinition = "TIMESTAMP DEFAULT CURRENT_TIMESTAMP", insertable = false, updatable = false)
public Date getCreateDate() {
@@ -55,4 +173,5 @@ public class InfraHostOS {
public void setCreateDate(Date createDate) {
this.createDate = createDate;
}
+
}
diff --git a/src/main/java/com/loafle/overflow/model/infra/InfraZone.java b/src/main/java/com/loafle/overflow/model/infra/InfraZone.java
index c51280e..08eca2b 100644
--- a/src/main/java/com/loafle/overflow/model/infra/InfraZone.java
+++ b/src/main/java/com/loafle/overflow/model/infra/InfraZone.java
@@ -2,7 +2,6 @@ package com.loafle.overflow.model.infra;
import javax.persistence.*;
-import com.loafle.overflow.model.meta.MetaIPType;
import com.loafle.overflow.model.meta.MetaTargetZoneType;
/**
@@ -16,9 +15,10 @@ public class InfraZone extends Infra {
private String network;
private String iface;
- private MetaIPType metaIPType;
- private String address;
+ private String addressV4;
+ private String addressV6;
private String mac;
+ private String gateway;
@ManyToOne
@JoinColumn(name = "META_TARGET_ZONE_TYPE_ID", nullable = true)
@@ -30,7 +30,6 @@ public class InfraZone extends Infra {
this.metaTargetZoneType = metaTargetZoneType;
}
-
@Basic
@Column(name = "NETWORK", nullable = true)
public String getNetwork() {
@@ -51,26 +50,6 @@ public class InfraZone extends Infra {
this.iface = iface;
}
- @ManyToOne
- @JoinColumn(name = "META_IP_TYPE_ID", nullable = true)
- public MetaIPType getMetaIPType() {
- return metaIPType;
- }
-
- public void setMetaIPType(MetaIPType metaIPType) {
- this.metaIPType = metaIPType;
- }
-
- @Basic
- @Column(name = "ADDRESS", nullable = true)
- public String getAddress() {
- return address;
- }
-
- public void setAddress(String address) {
- this.address = address;
- }
-
@Basic
@Column(name = "MAC", nullable = true)
public String getMac() {
@@ -80,4 +59,47 @@ public class InfraZone extends Infra {
public void setMac(String mac) {
this.mac = mac;
}
+
+ @Basic
+ @Column(name = "GATEWAY", nullable = true)
+ public String getGateway() {
+ return gateway;
+ }
+
+ public void setGateway(String gateway) {
+ this.gateway = gateway;
+ }
+
+ /**
+ * @return the addressV4
+ */
+ @Basic
+ @Column(name = "ADDRESS_V4", nullable = true)
+ public String getAddressV4() {
+ return addressV4;
+ }
+
+ /**
+ * @param addressV4 the addressV4 to set
+ */
+ public void setAddressV4(String addressV4) {
+ this.addressV4 = addressV4;
+ }
+
+ /**
+ * @return the addressV6
+ */
+ @Basic
+ @Column(name = "ADDRESS_V6", nullable = true)
+ public String getAddressV6() {
+ return addressV6;
+ }
+
+ /**
+ * @param addressV6 the addressV6 to set
+ */
+ public void setAddressV6(String addressV6) {
+ this.addressV6 = addressV6;
+ }
+
}
diff --git a/src/main/java/com/loafle/overflow/model/noauthprobe/NoAuthProbe.java b/src/main/java/com/loafle/overflow/model/noauthprobe/NoAuthProbe.java
index e4cd30f..a3a42c8 100644
--- a/src/main/java/com/loafle/overflow/model/noauthprobe/NoAuthProbe.java
+++ b/src/main/java/com/loafle/overflow/model/noauthprobe/NoAuthProbe.java
@@ -14,13 +14,13 @@ import java.util.Date;
@Table(name = "NOAUTH_PROBE", schema = "public")
public class NoAuthProbe {
private Long id;
- private String description;
- private MetaNoAuthProbeStatus metaNoAuthProbeStatus;
- private String tempProbeKey;
- private Date connectDate;
- private String apiKey;
private Domain domain;
private Probe probe;
+ private MetaNoAuthProbeStatus metaNoAuthProbeStatus;
+ private String description;
+ private String tempProbeKey;
+ private String apiKey;
+ private Date connectDate;
private String connectAddress;
private Date createDate;
diff --git a/src/main/java/com/loafle/overflow/model/noauthprobe/NoAuthProbeDescriptionHost.java b/src/main/java/com/loafle/overflow/model/noauthprobe/NoAuthProbeDescriptionHost.java
deleted file mode 100644
index 02a9419..0000000
--- a/src/main/java/com/loafle/overflow/model/noauthprobe/NoAuthProbeDescriptionHost.java
+++ /dev/null
@@ -1,116 +0,0 @@
-package com.loafle.overflow.model.noauthprobe;
-
-import org.codehaus.jackson.annotate.JsonProperty;
-
-/**
- * NoAuthProbeDescriptionHost
- */
-public class NoAuthProbeDescriptionHost {
- private String name;
- private String os;
- private String platform;
- private String platformFamily;
- private String platformVersion;
- private String kernelVersion;
- private String hostID;
-
- /**
- * @return the name
- */
- public String getName() {
- return name;
- }
-
- /**
- * @param name the name to set
- */
- public void setName(String name) {
- this.name = name;
- }
-
- /**
- * @return the os
- */
- @JsonProperty("os")
- public String getOS() {
- return os;
- }
-
- /**
- * @param os the os to set
- */
- @JsonProperty("os")
- public void setOS(String os) {
- this.os = os;
- }
-
- /**
- * @return the platform
- */
- public String getPlatform() {
- return platform;
- }
-
- /**
- * @param platform the platform to set
- */
- public void setPlatform(String platform) {
- this.platform = platform;
- }
-
- /**
- * @return the platformFamily
- */
- public String getPlatformFamily() {
- return platformFamily;
- }
-
- /**
- * @param platformFamily the platformFamily to set
- */
- public void setPlatformFamily(String platformFamily) {
- this.platformFamily = platformFamily;
- }
-
- /**
- * @return the platformVersion
- */
- public String getPlatformVersion() {
- return platformVersion;
- }
-
- /**
- * @param platformVersion the platformVersion to set
- */
- public void setPlatformVersion(String platformVersion) {
- this.platformVersion = platformVersion;
- }
-
- /**
- * @return the kernelVersion
- */
- public String getKernelVersion() {
- return kernelVersion;
- }
-
- /**
- * @param kernelVersion the kernelVersion to set
- */
- public void setKernelVersion(String kernelVersion) {
- this.kernelVersion = kernelVersion;
- }
-
- /**
- * @return the hostID
- */
- public String getHostID() {
- return hostID;
- }
-
- /**
- * @param hostID the hostID to set
- */
- public void setHostID(String hostID) {
- this.hostID = hostID;
- }
-}
\ No newline at end of file
diff --git a/src/main/java/com/loafle/overflow/model/noauthprobe/NoAuthProbeDescriptionNetwork.java b/src/main/java/com/loafle/overflow/model/noauthprobe/NoAuthProbeDescriptionNetwork.java
deleted file mode 100644
index c6e7802..0000000
--- a/src/main/java/com/loafle/overflow/model/noauthprobe/NoAuthProbeDescriptionNetwork.java
+++ /dev/null
@@ -1,68 +0,0 @@
-package com.loafle.overflow.model.noauthprobe;
-
-/**
- * NoAuthProbeDescriptionNetwork
- */
-public class NoAuthProbeDescriptionNetwork {
- private String name;
- private String address;
- private String gateway;
- private String macAddress;
-
- /**
- * @return the name
- */
- public String getName() {
- return name;
- }
-
- /**
- * @param name the name to set
- */
- public void setName(String name) {
- this.name = name;
- }
-
- /**
- * @return the address
- */
- public String getAddress() {
- return address;
- }
-
- /**
- * @param address the address to set
- */
- public void setAddress(String address) {
- this.address = address;
- }
-
- /**
- * @return the gateway
- */
- public String getGateway() {
- return gateway;
- }
-
- /**
- * @param gateway the gateway to set
- */
- public void setGateway(String gateway) {
- this.gateway = gateway;
- }
-
- /**
- * @return the macAddress
- */
- public String getMacAddress() {
- return macAddress;
- }
-
- /**
- * @param macAddress the macAddress to set
- */
- public void setMacAddress(String macAddress) {
- this.macAddress = macAddress;
- }
-
-}
\ No newline at end of file
diff --git a/src/main/java/com/loafle/overflow/model/noauthprobe/NoAuthProbeDescription.java b/src/main/java/com/loafle/overflow/model/noauthprobe/NoAuthProbeDescription.java
index 5be9291..0e97266 100644
--- a/src/main/java/com/loafle/overflow/model/noauthprobe/NoAuthProbeDescription.java
+++ b/src/main/java/com/loafle/overflow/model/noauthprobe/NoAuthProbeDescription.java
@@ -1,38 +1,43 @@
package com.loafle.overflow.model.noauthprobe;
+import java.util.List;
+
+import com.loafle.overflow.model.infra.InfraHost;
+import com.loafle.overflow.model.infra.InfraZone;
+
/**
* NoAuthProbeDescription
*/
public class NoAuthProbeDescription {
- private NoAuthProbeDescriptionHost host;
- private NoAuthProbeDescriptionNetwork network;
+ private InfraHost infraHost;
+ private List infraZones;
/**
- * @return the host
+ * @return the infraHost
*/
- public NoAuthProbeDescriptionHost getHost() {
- return host;
+ public InfraHost getInfraHost() {
+ return infraHost;
}
/**
* @param host the host to set
*/
- public void setHost(NoAuthProbeDescriptionHost host) {
- this.host = host;
+ public void setInfraHost(InfraHost infraHost) {
+ this.infraHost = infraHost;
}
/**
- * @return the network
+ * @return the infraZones
*/
- public NoAuthProbeDescriptionNetwork getNetwork() {
- return network;
+ public List getInfraZones() {
+ return infraZones;
}
/**
- * @param network the network to set
+ * @param infraZones the infraZones to set
*/
- public void setNetwork(NoAuthProbeDescriptionNetwork network) {
- this.network = network;
+ public void setInfraZones(List infraZones) {
+ this.infraZones = infraZones;
}
}
\ No newline at end of file
@@ -1,38 +1,43 @@
}
/**
- * @param host the host to set
+ * @param infraHost the infraHost to set
*/